spoon.transports.transports.TransportException

Package spoon :: Package transports :: Module transports :: Class TransportException |
[show private | hide private]
[frames | no frames]

## Class TransportException

    Exception --+
                |
               TransportException

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net